import { NgxGistService } from './ngx-gist.service';
import { NgxGist } from './ngx-gist.model';
import { OnInit } from '@angular/core';
import { Language } from 'highlight.js';
import * as i0 from "@angular/core";
export declare class NgxGistComponent implements OnInit {
    private readonly document;
    private readonly ngxGistService;
    constructor(document: Document, ngxGistService: NgxGistService);
    codeSnippet: string | null;
    private htmlLinkElement;
    /**
     * Display in the DOM only the selected filename from the gists files array.
     *
     * TODO: Make this possible for string array input.
     *
     * Default: `undefined`
     */
    displayOnlyFileName?: string;
    /**
     * Provide a static gist model here directly which will be displayed if
     * no `gistId` is provided for remote fetching. Also this model will be
     * displayed should a fetch fail when retrieving `gistId`, or overwritten
     * once the pertaining `gistId` data is fetched.
     *
     * Default: `undefined`
     */
    gist?: NgxGist;
    private readonly gistIdSubject;
    readonly gistIdChanges: import("rxjs").Observable<string>;
    /**
     * Provide the GitHub gist id to be fetched and loaded. This can be found in
     * URL of the gists you create. For example the id `TH1515th31DT0C0PY` in:
     * https://gist.github.com/FakeUserName/TH1515th31DT0C0PY
     *
     * Alternatively, provide a value directly in the sibling input `gist`.
     */
    set gistId(value: string);
    /**
     * When defined, override automatic language detection [and styling] and
     * treat all gists as this lanuage.
     *
     * See supported languages here:
     * https://github.com/highlightjs/highlight.js/blob/main/SUPPORTED_LANGUAGES.md
     *
     * Default: `undefined`
     */
    languageName?: Language['name'];
    /**
     * Define a material core theme to apply. Ideally, you should already have
     * your global material theme set at the root of your project so try to
     * avoid using this if possible. Note: These are also loaded from a CDN.
     *
     * See theming Angular Material: https://material.angular.io/guide/theming
     *
     * CDN used: `https://unpkg.com`
     *
     * Default: `undefined`
     */
    materialTheme: 'deeppurple-amber' | 'indigo-pink' | 'pink-bluegrey' | 'purple-green' | undefined;
    /**
     * Cache the GitHub gist request in local memory for 24 hours. GitHub has a
     * request limit, so this helps in reducing bandwidth. Loads previously
     * fetched gist content from the users machine.
     *
     * Default: `true`
     */
    useCache: boolean;
    ngOnInit(): Promise<void>;
    getHighlightJsContent(value: string): string;
    private fetchAndSetGist;
    private setTheme;
    static ɵfac: i0.ɵɵFactoryDeclaration<NgxGistComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<NgxGistComponent, "ngx-gist", never, { "displayOnlyFileName": "displayOnlyFileName"; "gist": "gist"; "gistId": "gistId"; "languageName": "languageName"; "materialTheme": "materialTheme"; "useCache": "useCache"; }, {}, never, never, false>;
}
